@@ -1,4 +1,6 @@
-from convoy.api import application, delivery_attempts, endpoint, event, event_delivery, group
+from re import sub
+from convoy.api import delivery_attempts, endpoint, event, event_delivery, group, source, subscription
+from convoy.utils import webhook
 
 class Convoy():
     """Initializes the main Convoy Object.
@@ -19,9 +21,11 @@ class Convoy():
     }
     """
     def __init__(self, config):
-        self.applications = application.Application(config)
-        self.deliveryAttempts = delivery_attempts.DeliveryAttempt(config)
+        self.delivery_attempt = delivery_attempts.DeliveryAttempt(config)
         self.endpoint = endpoint.Endpoint(config)
-        self.eventDelivery = event_delivery.EventDelivery(config)
+        self.event_delivery = event_delivery.EventDelivery(config)
         self.event = event.Event(config)
-        self.group = group.Group(config)
\ No newline at end of file
+        self.group = group.Group(config)
+        self.source = source.Source(config)
+        self.subscription = subscription.Subscription(config)
+        self.webhook = webhook.Webhook()
\ No newline at end of file
