@@ -1,6 +1,6 @@
-'''
+"""
 You can use these dict objects to create your own data.
-'''
+"""
 
 Config = {
         #Username used for basic authentication
@@ -13,15 +13,8 @@ Config = {
         "uri": ""
     }
 
-NewApplication = {
-                "name": "",
-                "support_email": "",
-                "secret": ""
-                }
-
-
 NewEvent = {
-            "app_id": "",
+            "endpoint_id": "",
             "event_type": "",
             "data": {
                     "event": "",
